@@ -3,7 +3,7 @@ use warnings;
 
 package Template::Pure;
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use DOM::Tiny;
 use Scalar::Util;
@@ -87,7 +87,11 @@ sub _process_dom_recursive {
       $self->_process_obj($dom, $data, $action_proto, %match_spec);
     } else {
       my $value = $self->_value_from_action_proto($dom, $data, $action_proto, %match_spec);
-      $self->_process_match_spec($dom, $value, %match_spec);
+      if(Scalar::Util::blessed($value) && $value->isa('Template::Pure')) {
+        $self->_process_obj($dom, $data, $value, %match_spec);
+      } else {
+        $self->_process_match_spec($dom, $value, %match_spec);
+      }
     }
   }
 
@@ -96,11 +100,35 @@ sub _process_dom_recursive {
 
 sub _process_obj {
   my ($self, $dom, $data, $obj, %match_spec) = @_;
+  my $css = $match_spec{css};
+
   if($obj->isa(ref $self)) {
-    my $value = $self->_value_from_template_obj($dom, $data, $obj, %match_spec);
-    $self->_process_match_spec($dom, $value, %match_spec);
+    if($css eq '.') {
+      my $value = $self->_value_from_template_obj($dom, $data, $obj, %match_spec);
+      $self->_process_mode($dom, $value, %match_spec);
+    } else {
+      my $collection = $dom->find($css);
+      $collection->each(sub {
+
+        my $content;
+        if($match_spec{target} eq 'content') {
+          $content = $self->encoded_string($_->content);
+        } elsif($match_spec{target} eq 'node') {
+          $content = $self->encoded_string($_->to_string);
+        } elsif(my $attr = ${$match_spec{target}}) {
+          $content = $_->attr($attr);
+        }
+
+        my $new_data = Template::Pure::DataProxy->new(
+          $data->value,
+          content => $self->encoded_string($content));
+
+        my $value = $self->encoded_string($obj->render($new_data));
+
+        $self->_process_mode($_, $value, %match_spec);
+      });
+    }
   } elsif($obj->can('TO_HTML')) {
-    my $css = $match_spec{css};
     if($css eq '.') {
       my $value = $obj->TO_HTML($self, $dom, $data->value);
       $self->_process_mode($dom, $value, %match_spec);
@@ -114,7 +142,6 @@ sub _process_obj {
   } else {
     die "Can't process object of type $obj.";
   }
-
 }
 
 sub _value_from_action_proto {
@@ -684,6 +711,62 @@ current data context, for example:
 
 In this case the value of the node indicated by '#last_name' will be set to 'Lovecraft'.
 
+B<NOTE>: If your scalar action returns a L<Template::Pure> object, it will render as if
+it was an object action as described below L</Object - Set the match value to another Pure Template>.
+
+For example:
+
+    my $wrapper_html = qq[
+      <section>Example Wrapped Stuff</section>];
+
+    my $wrapper = Template::Pure->new(
+      template=>$wrapper_html,
+      directives=> [
+        'section' => 'content',
+      ]);
+
+    my $template = qq[
+     <html>
+        <head>
+          <title>Title Goes Here!</title>
+        </head>
+        <body>
+          <p>Hi Di Ho!</p>
+        </body>
+      </html>    
+    ];
+
+    my @directives = (
+      title => 'title | upper',
+      body => 'info',
+    );
+
+    my $pure = Template::Pure->new(
+      template => $template,
+      directives => \@directives);
+
+    my $data = +{
+      title => 'Scalar objects',
+      info => $wrapper,
+    };
+
+    ok my $string = $pure->render($data);
+
+Results in:
+
+   <html>
+      <head>
+        <title>SCALAR OBJECTS</title>
+      </head>
+      <body>
+    <section>
+        <p>Hi Di Ho!</p>
+      </section></body>
+    </html>
+
+This feature is currently only active for scalar actions but may be extended to other action
+types in the future.
+
 =head2 ScalarRef - Set the value to the results of a match
 
 There may be times when you want to set the value of something to an existing
